********************************************************************************
/*
Project global distribution from 2025 to 2050 with distribution neutral assumptions
from 1990 for specific country
*/
********************************************************************************

*******************************************
*** (1) BACKGROUND FILES FOR PROJECTION ***
*******************************************
// add growth rates up to 2050; WDI+MPO+WEO until 2028 and historical(1990-19)
// use pass-through of 0.70 for consumption based surveys and 1 for income based surveys
use "${impath}GDP_GEP202406_app.dta", clear
replace gbaseline = gdppc_pip_hist1990_2019 if source=="HistAvg" // Change historical average to 1990-2019

merge m:1 code using "${inputdata}PIP\PIP_countries_202409.dta", keep(1 3) keepusing(welfare_type) nogen
replace gbaseline = gbaseline * 0.7 if inlist(welfare_type,1,.) // missing or consumption; welfare_type==2 gets pass-through of 1
replace gprecovid = gprecovid * 0.7 if inlist(welfare_type,1,.) // missing or consumption; welfare_type==2 gets pass-through of 1
keep if inrange(year,2020,2050)
keep code year gbaseline gprecovid
reshape wide g*, i(code) j(year)
tempfile grrates
save `grrates', replace

// population necessary for projection
use "${inputdata}Other\Population_202409", clear
keep if coverage=="national"
keep code year pop
replace pop = pop/1000															// population per 1000 bin
keep if inrange(year,2021,2050)
reshape wide pop, i(code) j(year)
tempfile popu
save 	`popu', replace


*************************************
*** (2) PROJECTION FROM 2025-2050 ***
*************************************

use "${inputdata}PIP/GlobalDist1000bins_1990_2024_3pr24.dta", clear  

keep if year==2024
ren pop pop2024 
ren welf welf2024

keep country code inPIP region_pip quantile pop2024 welf2024 

merge m:1 code using `grrates', nogen keepusing(gbaseline*)
merge m:1 code using `popu'	  , nogen

forval yr = 2025/2050 {
	local lagyr = `yr' - 1
	gen welf`yr' = welf`lagyr' * (1 + gbaseline`yr')
}
drop gbaseline*

*************************************************
*** (3) REGIONAL AVERAGE FOR THOSE NOT IN PIP ***
*************************************************

// replace welfare with regional average for countries not in pip (and missing precovid and welfare values)
// replace missing values with regional average
foreach v of varlist welf2025-welf2050 {
	local yr = substr("`v'",-4,.)
	replace `v' = . if inPIP=="No"												// all countries with no survey in PIP
	
	preserve																	// 1000 regional bins to calculate average per regional bin
	drop quantile
	egen id = group(region_pip)												
	egen quantile = xtile(`v'), nq(1000) by(id) weight(pop`yr')
	collapse `v' [aw=pop`yr'], by(region_pip quantile)
	drop if missing(`v')
	ren `v' `v'_m
	tempfile regional_average
	save 	`regional_average'
	restore

	merge m:1 region_pip quantile using `regional_average', nogen

	bys region_pip (quantile): replace `v'_m = `v'_m[_n-1] if missing(`v'_m)	// same average so missing quantile value using xtile
	replace `v' = `v'_m if missing(`v')											// replace missing values by regional average for each bin
	drop `v'_m
}

reshape long pop welf, i(country code region inPIP quantile) j(year)

keep country code region_pip quantile year pop welf 

label var year 					"Year"
label var country				"Country names"
label var code 					"Country ISO3c code"
label var region_pip 			"PIP regions"
label var quantile 				"Bin number"
label var pop 					"Population of each bin in millions"
label var welf					"Average daily per capita welfare of bin in 2017 PPP USD"

keep if inrange(year, 2025, 2050)
order country code region_pip year quantile pop welf
sort  code year quantile
compress

save "${impath}DistributionNeutralProjection_2025_2050_w1990.dta", replace

********************************************************************************

exit