********************************************************************************
*** Using welfare vector in 2024 and project to 2100 using SSP forecasts (Appendix)
********************************************************************************
clear all

cd "${dopath}" // Need to specify for the povsim ado to work

cap erase "GlobalProjectedDist3_$stryear_$endyear.dta"
cap erase "povout3"

global stryear = 2024
global endyear = 2050

********************************************************************************

use "${inputdata}Growth/ssp.dta", clear											// SSP projections
keep if inlist(scenario,"SSP2","SSP3","SSP5")									// Scenarios for Appendix
merge m:1 code using "${inputdata}PIP/PIP_countries_202409.dta", keep(1 3) keepusing(welfare_type) nogen
replace growth = growth * 0.7 if inlist(welfare_type,1)							// applying a passthrough of 0.7 for surveys with consumption data
reshape wide growth gini pop, i(code scenario) j(year)
tempfile sspgrowth
save 	`sspgrowth'


use "${inputdata}PIP/GlobalDist1000bins_2024_3pr24.dta", clear 					
keep if year==$stryear
ren welf welf$stryear
keep code quantile welf$stryear

joinby code using `sspgrowth'													
drop growth$stryear

tempfile datasofar
save 	`datasofar'

local y1 = $stryear + 1

levelsof code, local(levels) 

local one ABW AFG AGO ALB AND ARE ARG ARM ASM ATG AUS AUT AZE BDI BEL BEN BFA BGD BGR BHR BHS BIH BLR BLZ BMU ///
BOL BRA BRB BRN BTN BWA CAF CAN CHE CHI CHL CHN CIV CMR COD COG COL COM CPV CRI CUB CUW CYM CYP CZE ///
DEU DJI DMA DNK DOM DZA ECU EGY ERI ESP EST ETH FIN FJI FRA FRO FSM GAB GBR GEO GHA GIB GIN GMB GNB ///
GNQ GRC GRD GRL GTM GUM GUY HKG HND HRV HTI HUN IDN IMN IND IRL IRN IRQ ISL ISR ITA JAM JOR JPN KAZ ///
KEN KGZ KHM KIR KNA KOR KWT LAO LBN ///

local two LBR LBY LCA LIE LKA LSO LTU LUX LVA MAC MAF MAR MCO MDA MDG MDV MEX MHL MKD MLI MLT MMR MNE MNG MNP ///
MOZ MRT MUS MWI MYS NAM NCL NER NGA NIC NLD NOR NPL NRU NZL OMN PAK PAN PER PHL PLW PNG POL PRI PRK ///
PRT PRY PSE PYF QAT ROU RUS RWA SAU SDN SEN SGP SLB SLE SLV SMR SOM SRB SSD STP SUR SVK SVN SWE SWZ ///
SXM SYC SYR TCA TCD TGO THA TJK TKM TLS TON TTO TUN TUR TUV TWN TZA UGA UKR URY USA UZB VCT VEN VGB ///
VIR VNM VUT WSM XKX YEM ZAF ZMB ZWE ///

local levels_f : list levels - two

foreach ccc of local levels_f {

	foreach s in SSP2 SSP3 SSP5 { 					 							// Scenarios for Appendix
		
		forval yr = `y1'/$endyear {
			
			qui local yr0 = `yr' - 1
			
			qui use "`datasofar'", clear
			
			qui keep if code=="`ccc'" & scenario=="`s'"
			
			di "******* code: `ccc'; scenario: `s'; year: `yr' *******" 		// to keep track of the loop
			
			qui {
				
				keep code quantile welf`yr0' gini`yr' gini`yr0' growth`yr'
				
				sum growth`yr'
				local grw = r(mean)/100
				
				sum welf`yr0' if quantile<=400, d								// need bottom 40 share for spp; spp goes into povsim not gini
				local b40sum = r(sum)
				sum welf`yr0', d
				local totalsum = r(sum)
				local b40share = `b40sum'/`totalsum'

				local alpha = gini`yr'/gini`yr0' - 1							// change in gini
				
				local spp = -`alpha'*(1+`grw')*(0.4/`b40share'-1)				// shared prosperity premium used for povsim instead of gini

				povsim welf`yr0', type(welfare) gic(l) growth(`grw') premium(`spp') name(povout3) repetitions(1) replace
				
				use povout3, clear												// cleanup out and save the latest year welfare vector
				keep welfare1 mtile1
				ren mtile1 		quantile
				ren welfare1 	welf`yr'
				gen code	 = "`ccc'"
				gen scenario = "`s'"
				
				merge 1:1 code quantile scenario using "`datasofar'", nogen update	// add the latest year welfare vector to use a baseline for next year
				save "`datasofar'", replace
				save "GlobalProjectedDist3_$stryear_$endyear.dta", replace
			}
		}

	}
}
// \
use "GlobalProjectedDist3_$stryear_$endyear.dta", clear
save "${impath}GlobalProjectedDist3_$stryear_$endyear.dta", replace					
cap erase "GlobalProjectedDist3_$stryear_$endyear.dta"
cap erase "povout3.dta"

********************************************************************************
exit