********************************************************************************
/*
Calculate inequality for the world
*/
********************************************************************************
// calculate inequality
use "${inputdata}PIP\GlobalDist1000bins_1990_2024_3pr24.dta", clear 
gen gini = .
sum year
forval yr = `r(min)'/`r(max)' {
	qui ineqdeco welf [aw=pop]  if year==`yr'
	replace gini = `r(gini)' * 100 if year==`yr'
} 
collapse welf gini (rawsum) pop [aw=pop], by(year)
gen scenario="historical"
tempfile hisdata
save 	`hisdata'


use "${impath}GlobalProjectedDist_2050_SSP_1_4.dta", clear	
drop pop2051-pop2100 gini*
foreach s in SSP1 SSP4 {	
	preserve 
	keep if scenario=="`s'"
	forval yr = 2024/2050 {
		qui ineqdeco welf`yr' [aw=pop`yr']  
		gen gini`yr' = `r(gini)' * 100 
	}
	keep code quantile scenario pop* welf* gini*
	reshape long gini welf pop, i(code quantile scenario) j(year)
	collapse welf gini pop [aw=pop], by(year scenario)
	cap append using `inedata'
	tempfile inedata
	save 	`inedata'
	restore
}

// use "${impath}GlobalProjectedDist_2050_SSP_2_3_5.dta", clear	// Only run for Appendix's results
// drop pop2051-pop2100 gini*
// foreach s in SSP2 SSP3 SSP5 {	
// 	preserve 
// 	keep if scenario=="`s'"
// 	forval yr = 2024/2050 {
// 		qui ineqdeco welf`yr' [aw=pop`yr']  
// 		gen gini`yr' = `r(gini)' * 100 
// 	}
// 	keep code quantile scenario pop* welf* gini*
// 	reshape long gini welf pop, i(code quantile scenario) j(year)
// 	collapse welf gini pop [aw=pop], by(year scenario)
// 	cap append using `inedata'
// 	tempfile inedata
// 	save 	`inedata'
// 	restore
// }
//
// use "${impath}DistributionNeutralProjection_2025_2050_w1990.dta", clear // Only run for Appendix's results
// gen gini = .
// sum year
// forval yr = `r(min)'/`r(max)' {
// 	qui ineqdeco welf [aw=pop]  if year==`yr'
// 	replace gini = `r(gini)' * 100 if year==`yr'
// } 
// collapse welf gini (rawsum) pop [aw=pop], by(year)
// gen scenario="dist-neutral_w1990"
// tempfile dist_neutral_w1990
// save 	`dist_neutral_w1990'
//
// use "${impath}DistributionNeutralProjection_2025_2050_w1990FY95.dta", clear // Only run for Appendix's results
// gen gini = .
// sum year
// forval yr = `r(min)'/`r(max)' {
// 	qui ineqdeco welf [aw=pop]  if year==`yr'
// 	replace gini = `r(gini)' * 100 if year==`yr'
// } 
// collapse welf gini (rawsum) pop [aw=pop], by(year)
// gen scenario="dist-neutral_w1990FY95"
// tempfile dist_neutral_w1990FY95
// save 	`dist_neutral_w1990FY95'
//
// use "${impath}DistributionNeutralProjection_2025_2050_w1990FY24.dta", clear // Only run for Appendix's results
// gen gini = .
// sum year
// forval yr = `r(min)'/`r(max)' {
// 	qui ineqdeco welf [aw=pop]  if year==`yr'
// 	replace gini = `r(gini)' * 100 if year==`yr'
// } 
// collapse welf gini (rawsum) pop [aw=pop], by(year)
// gen scenario="dist-neutral_w1990FY24"
// tempfile dist_neutral_w1990FY24
// save 	`dist_neutral_w1990FY24'

use "${impath}DistributionNeutralProjection_2025_2050.dta", clear 
gen gini = .
sum year
forval yr = `r(min)'/`r(max)' {
	qui ineqdeco welf [aw=pop]  if year==`yr'
	replace gini = `r(gini)' * 100 if year==`yr'
} 
collapse welf gini (rawsum) pop [aw=pop], by(year)
gen scenario="dist-neutral"
tempfile dist_neutral
save 	`dist_neutral'

append using `inedata'
append using `hisdata'
// append using `dist_neutral_w1990'
// append using `dist_neutral_w1990FY24'
// append using `dist_neutral_w1990FY95'

save "${output}GlobalInequalityData_All.dta", replace

********************************************************************************
exit