********************************************************************************
/*
Growth rates with distribution neutral assumptions from 1990 for specific country or income group
*/
********************************************************************************

*** Create files for Income groups

use "${inputdata}Other\CLASS_FY24.dta", clear
keep if year_fiscal==2024
keep code region region_pip incgroup_historical ida_historical fcv_historical
duplicates drop
ren region region_wb
ren incgroup_historical incgroupFY24
ren ida_historical 		idaFY24
ren fcv_historical 		fcvFY24 

replace incgroupFY24 = "LIC"  if incgroupFY24 == "Low income"
replace incgroupFY24 = "LMIC" if incgroupFY24 == "Lower middle income"
replace incgroupFY24 = "UMIC" if incgroupFY24 == "Upper middle income"
replace incgroupFY24 = "HIC"  if incgroupFY24 == "High income"

tempfile inc_grp24
save    `inc_grp24'

use "${inputdata}Other\CLASS_FY24.dta", clear
keep if year_fiscal==1995
keep code region region_pip incgroup_historical ida_historical fcv_historical
duplicates drop
ren region region_wb
ren incgroup_historical incgroupFY95
ren ida_historical 		idaFY95
ren fcv_historical 		fcvFY95

replace incgroupFY95 = "LIC"  if incgroupFY95 == "Low income"
replace incgroupFY95 = "LMIC" if incgroupFY95 == "Lower middle income"
replace incgroupFY95 = "UMIC" if incgroupFY95 == "Upper middle income"
replace incgroupFY95 = "HIC"  if incgroupFY95 == "High income"

tempfile inc_grp95
save    `inc_grp95'

*** Calculate historial growth rate with GDP data from PIP

pip tables, table(gdp) $pipoptions clear
destring value, ignore("NA") replace 
keep if data_level=="national"
drop data_level
ren country_code code
ren value gdppc_pip
gen lngdp = ln(gdppc_pip)

// Average historical (1990-2019) growth rates
gen gdppc_pip_hist1990_2019 = .
qui levelsof code
foreach cd in `r(levels)' {
	clear results
	capture reg lngdp year if code=="`cd'" & inrange(year,1990,2019) 
	capture replace gdppc_pip_hist1990_2019 = exp(_b[year])-1 if code=="`cd'" 
}
replace gdppc_pip_hist1990_2019 = gdppc_pip_hist1990_2019 

// Average historical (1990-2019) growth rates for projection past 2022 (and for FY24)
merge m:1 code using `inc_grp24', keepusing(incgroupFY24) keep(3) nogen

gen gdppc_pip_hist1990_2019FY24 = .
qui levels incgroupFY24
foreach cd in `r(levels)' {
	clear results
	capture reg lngdp year if incgroupFY24=="`cd'" & inrange(year,1990,2019) 
	capture replace gdppc_pip_hist1990_2019FY24 = exp(_b[year])-1 if incgroupFY24=="`cd'"
}
replace gdppc_pip_hist1990_2019FY24 = gdppc_pip_hist1990_2019FY24 

// Average historical (1990-2019) growth rates for projection past 2022 (and for FY24)
merge m:1 code using `inc_grp95', keepusing(incgroupFY95) keep(3) nogen

gen gdppc_pip_hist1990_2019FY95 = .
qui levels incgroupFY95
foreach cd in `r(levels)' {
	clear results
	capture reg lngdp year if incgroupFY95=="`cd'" & inrange(year,1990,2019) 
	capture replace gdppc_pip_hist1990_2019FY95 = exp(_b[year])-1 if incgroupFY95=="`cd'"
}

replace gdppc_pip_hist1990_2019FY95 = gdppc_pip_hist1990_2019FY95

keep code year gdppc_pip_hist1990_2019 gdppc_pip_hist1990_2019FY24 gdppc_pip_hist1990_2019FY95

label var gdppc_pip_hist1990_2019   "PIP GDP/capita historical growth 2010-2019"
label var gdppc_pip_hist1990_2019FY24 "PIP GDP/capita historical growth 1990-2019 for income group FY24"
label var gdppc_pip_hist1990_2019FY95 "PIP GDP/capita historical growth 1990-2019 for income group FY95"
isid code year

*** Extend series to 2050 ***
levelsof code 
foreach ccc in `r(levels)' {										// take the last year of each country and add rows to fillin to 2050
	qui sum year if code=="`ccc'"	
	local   expandyr = (2050 + 1) - `r(max)' 		
	expand `expandyr' if year==`r(max)' & code=="`ccc'", gen(tag)
	
	replace year = `r(max)'+1 if tag==1 & code=="`ccc'"				// renumber the years for the added rows				
	bys tag (year): replace year = year[_n-1]+1 if _n!=1 & tag==1 & code=="`ccc'"
	
	foreach var of varlist gdppc* {	// set the values of the added rows to missing if they are repeated from last row
		replace `var' = . if tag==1	
	}
	
	drop tag
} 

bys code (year): replace gdppc_pip_hist1990_2019 = gdppc_pip_hist1990_2019[_n-1] if missing(gdppc_pip_hist1990_2019)
bys code (year): replace gdppc_pip_hist1990_2019FY24 = gdppc_pip_hist1990_2019FY24[_n-1] if missing(gdppc_pip_hist1990_2019FY24)
bys code (year): replace gdppc_pip_hist1990_2019FY95 = gdppc_pip_hist1990_2019FY95[_n-1] if missing(gdppc_pip_hist1990_2019FY95)

tempfile gdp_pip
save    `gdp_pip'

use "${inputdata}Growth\GDP_GEP202406.dta", clear
merge 1:1 code year using `gdp_pip', keep(1 3) nogen

save "${impath}GDP_GEP202406_app.dta", replace

********************************************************************************

exit
