** figure 6 **

*A)
use "${inputdata}PIP/GlobalDist1000bins_1990_2024_3pr24.dta",clear

keep if inlist(year,1990,2019)
collapse welf (rawsum) pop [w=pop], by(country code year)
reshape wide welf pop, i(country code) j(year)
gen ann_growth = ((welf2019 / welf1990)^(1/(2019 - 1990)) - 1) * 100

keep if welf1990<101

gen log_welf1990 = log(welf1990)
	   
twoway (scatter ann_growth log_welf1990, mc(black)) ///
       (lfit ann_growth log_welf1990, lcolor(black) lwidth(thick) lpattern(solid)) ///
       (lfit ann_growth log_welf1990 [aw=pop1990], lcolor(black) lwidth(thick) lpattern(dash)), ///
       ytitle("Annualized growth 1990-2019, %") ///
       xtitle("Average income 1990, daily per capita 2017 PPP$") ///
       yscale(range(-4 8)) ///
	   xlabel(0 "1" 0.69 "2" 1.6 "5" 2.3 "10" 2.99 "20" 3.91 "50" 4.6 "100" 5.0 "150") ///
       yline(0, lcolor(gs12)) ///
       legend(order(2 "Unweighted" 3 "Weighted")) ///
       legend(position(6) ring(0) rows(1)) ///
       graphregion(color(white)) 

graph export "${figntab}Fig6A.png", replace as(png)

	   
*B)
use "${impath}DistributionNeutralProjection_2025_2050.dta", clear

preserve
use "${inputdata}PIP/GlobalDist1000bins_1990_2024_3pr24.dta",clear

keep country code region_pip year quantile pop welf
keep if year == 2024

tempfile bins_2024
save `bins_2024'
restore

append using `bins_2024'

keep if inlist(year,2024,2050)
collapse welf (rawsum) pop [w=pop], by(country code year)
reshape wide welf pop, i(country code) j(year)
gen ann_growth = ((welf2050 / welf2024)^(1/(2050 - 2024)) - 1) * 100

keep if ann_growth>-3

gen log_welf2024 = log(welf2024)
	   
twoway (scatter ann_growth log_welf2024, mc(black)) ///
       (lfit ann_growth log_welf2024, lcolor(black) lwidth(thick) lpattern(solid)) ///
       (lfit ann_growth log_welf2024 [aw=pop2024], lcolor(black) lwidth(thick) lpattern(dash)), ///
       ytitle("Annualized growth 2024-2050, %") ///
       xtitle("Average income 2024, daily per capita 2017 PPP$") ///
       yscale(range(-4 8)) ///
	   xlabel(0 "1" 0.69 "2" 1.6 "5" 2.3 "10" 2.99 "20" 3.91 "50" 4.6 "100" 5.0 "150") ///
       yline(0, lcolor(gs12)) ///
       legend(order(2 "Unweighted" 3 "Weighted")) ///
       legend(position(6) ring(0) rows(1)) ///
       graphregion(color(white)) 

graph export "${figntab}Fig6B.png", replace as(png)

*C)

use "${impath}GlobalProjectedDist_2050_SSP_1_4.dta", clear

keep if scenario == "SSP1"
keep code quantile *2024 *2050
reshape long welf pop, i(code quantile) j(year)
collapse welf (rawsum) pop [w=pop], by(code year)
reshape wide welf pop, i(code) j(year)
gen ann_growth = ((welf2050 / welf2024)^(1/(2050 - 2024)) - 1) * 100

keep if ann_growth<10

gen log_welf2024 = log(welf2024)
	   
twoway (scatter ann_growth log_welf2024, mc(black)) ///
       (lfit ann_growth log_welf2024, lcolor(black) lwidth(thick) lpattern(solid)) ///
       (lfit ann_growth log_welf2024 [aw=pop2024], lcolor(black) lwidth(thick) lpattern(dash)), ///
       ytitle("Annualized growth 2024-2050, %") ///
       xtitle("Average income 2024, daily per capita 2017 PPP$") ///
       yscale(range(-4 8)) /// 
	   ylabel(-2(2)8) ///
	   xlabel(0 "1" 0.69 "2" 1.6 "5" 2.3 "10" 2.99 "20" 3.91 "50" 4.6 "100" 5.0 "150") ///
       yline(0, lcolor(gs12)) ///
       legend(order(2 "Unweighted" 3 "Weighted")) ///
       legend(position(6) ring(0) rows(1)) ///
       graphregion(color(white)) 

graph export "${figntab}Fig6C.png", replace as(png)

*D)

use "${impath}GlobalProjectedDist_2050_SSP_1_4.dta", clear

keep if scenario == "SSP4"
keep code quantile *2024 *2050
reshape long welf pop, i(code quantile) j(year)
collapse welf (rawsum) pop [w=pop], by(code year)
reshape wide welf pop, i(code) j(year)
gen ann_growth = ((welf2050 / welf2024)^(1/(2050 - 2024)) - 1) * 100

keep if ann_growth<10

gen log_welf2024 = log(welf2024)
	   
twoway (scatter ann_growth log_welf2024, mc(black)) ///
       (lfit ann_growth log_welf2024, lcolor(black) lwidth(thick) lpattern(solid)) ///
       (lfit ann_growth log_welf2024 [aw=pop2024], lcolor(black) lwidth(thick) lpattern(dash)), ///
       ytitle("Annualized growth 2024-2050, %") ///
       xtitle("Average income 2024, daily per capita 2017 PPP$") ///
       yscale(range(-4 8)) /// 
	   ylabel(-2(2)8) ///
	   xlabel(0 "1" 0.69 "2" 1.6 "5" 2.3 "10" 2.99 "20" 3.91 "50" 4.6 "100" 5.0 "150") ///
       yline(0, lcolor(gs12)) ///
       legend(order(2 "Unweighted" 3 "Weighted")) ///
       legend(position(6) ring(0) rows(1)) ///
       graphregion(color(white)) 
	   
graph export "${figntab}Fig6D.png", replace as(png)


********************************************************************************
exit