********************************************************************************
/*
Comparing the forecasted growth rates with historical
*/
********************************************************************************

use "${inputdata}Other\CLASS_FY24.dta", clear
keep code incgroup_current														//keep the most recent classification 
duplicates drop 
tempfile incg
save 	`incg'

// income group population in latest year 
use "${inputdata}Other\Population_202409.dta", clear
keep if coverage=="national"
replace pop = pop																// population per 1000 bin
keep if year==2022
keep code pop
merge 1:1 code using `incg', nogen keep(3)
collapse (rawsum) pop, by(incgroup_current)
tempfile popu
save 	`popu', replace

use "${inputdata}Growth\GDP_GEP202406.dta", clear
keep if year==2050
gen gavg = gbaseline * 100
keep code gavg
gen scenario = "Hist2010"
tempfile historical
save 	`historical' 

use "${impath}GDP_GEP202406_app.dta", clear
replace gbaseline = gdppc_pip_hist1990_2019 if source=="HistAvg" 
keep if year==2050
gen gavg = gbaseline * 100
keep code gavg
gen scenario = "Hist1990"
tempfile historical_90
save 	`historical_90' 

use "${impath}GDP_GEP202406_app.dta", clear
replace gbaseline = gdppc_pip_hist1990_2019FY95 if source=="HistAvg" 
keep if year==2050
gen gavg = gbaseline * 100 
keep code gavg
gen scenario = "Hist1990FY95"
tempfile historical_90FY95
save 	`historical_90FY95' 

use "${impath}GDP_GEP202406_app.dta", clear
replace gbaseline = gdppc_pip_hist1990_2019FY24 if source=="HistAvg" 
keep if year==2050
gen gavg = gbaseline * 100 
keep code gavg
gen scenario = "Hist1990FY24"
tempfile historical_90FY24
save 	`historical_90FY24' 

use "${inputdata}Growth\ssp.dta", clear	
keep if year<=2050
reshape wide gini growth pop, i(code scenario) j(year)
drop growth* pop*
gen ann_ch_gini = ((gini2050/gini2024)^(1/(2050-2024)) - 1 ) *100
keep code scenario ann_ch_gini
tempfile ann_ch_gini
save 	`ann_ch_gini'

use "${inputdata}Growth\ssp.dta", clear	
keep if year<=2050
bys code scenario: egen gavg = mean(growth)
bys code scenario: egen gini_avg = mean(gini)

bys code scenario (year): gen gini_ch_avg = (gini/gini[_n-1] - 1) * 100

keep code scenario gavg gini_avg gini_ch_avg

append using `historical'
append using `historical_90'
append using `historical_90FY95'
append using `historical_90FY24'
append using `ann_ch_gini'
merge m:1 code using `incg', nogen keep(3)

bys incgroup_current scenario: egen gavg_inc = mean(gavg)
bys incgroup_current scenario: egen gini_avg_inc = mean(gini_avg)
bys incgroup_current scenario: egen gini_annch_avg_inc = mean(ann_ch_gini)
bys incgroup_current scenario: egen gini_ch_avg_inc = mean(gini_ch_avg)
merge m:1 incgroup_current using `popu', nogen keep(3)

collapse gavg_inc gini_avg_inc gini_ch_avg_inc gini_annch_avg_inc, by(incgroup_current scenario pop)							

gen 	incg = "LICs" if incgroup_current=="Low income"
replace incg = "LMICs" if incgroup_current=="Lower middle income"
replace incg = "UMICs" if incgroup_current=="Upper middle income"
replace incg = "HICs" if incgroup_current=="High income"

gen 	rank = 1 if incg=="LICs"
replace rank = 2 if incg=="LMICs"
replace rank = 3 if incg=="UMICs"
replace rank = 4 if incg=="HICs"

reshape wide gavg_inc gini_avg_inc gini_ch_avg_inc gini_annch_avg_inc, i(incgroup_current pop incg rank) j(scenario) string

drop gini_avg_inc* gini_annch_avg_inc* gini_ch_avg_incHist1990 gini_ch_avg_incHist1990FY24 gini_ch_avg_incHist1990FY95 gini_ch_avg_incHist2010

* Share population
egen tot_pop = total(pop)
gen sh_pop = pop / tot_pop
drop tot_pop
sort rank
// br

export delimited "${figntab}Table_1_3A_4A.csv", replace

********************************************************************************
exit